function _catch$1(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

var revalidate = function revalidate(request, response) {
  try {
    var slug = request.query.slug;
    var secret = request.query.secret; // Validate secret.

    if (secret !== process.env.DRUPAL_PREVIEW_SECRET) {
      return Promise.resolve(response.status(401).json({
        message: 'Invalid secret.'
      }));
    } // Validate slug.


    if (!slug) {
      return Promise.resolve(response.status(400).json({
        message: 'Invalid slug.'
      }));
    } // Fix for home slug.


    if (slug === process.env.NEXT_PUBLIC_DRUPAL_FRONT_PAGE) {
      slug = '/';
    }

    return Promise.resolve(_catch$1(function () {
      return Promise.resolve(response.revalidate(slug)).then(function () {
        return response.json({});
      });
    }, function (error) {
      return response.status(404).json({
        message: error.message
      });
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

var testApiCompatibility = function testApiCompatibility(contentTypes, drupal) {
  try {
    var _temp3 = function _temp3(_result) {
      if (_exit2) return _result;

      for (var _iterator = _createForOfIteratorHelperLoose(contentTypes), _step; !(_step = _iterator()).done;) {
        var type = _step.value;

        if (!Object.keys(index.links).includes(type)) {
          throw new Error("Content type " + type + " does not exist in the backend. \nSee here for documentation on content model mismatch: https://github.com/acquia/next-acms/wiki/Debugging-common-errors-with-Next.js-and-Drupal-integration#content-model-mismatch");
        }
      }
    };

    var _exit2;

    var index;

    var _temp4 = _catch(function () {
      return Promise.resolve(drupal.getIndex()).then(function (_drupal$getIndex) {
        index = _drupal$getIndex;
      });
    }, function (e) {
      throw new Error(e.message + '\n\n' + 'Failed to connect to the backend. See here for documentation about common reasons: \nhttps://github.com/acquia/next-acms/wiki/Debugging-common-errors-with-Next.js-and-Drupal-integration#incompatible-web-server-setup-or-incorrect-environment-variables-generated');
    });

    return Promise.resolve(_temp4 && _temp4.then ? _temp4.then(_temp3) : _temp3(_temp4));
  } catch (e) {
    return Promise.reject(e);
  }
};

exports.revalidate = revalidate;
exports.testApiCompatibility = testApiCompatibility;
//# sourceMappingURL=index.js.map
